#
# spec file for package gstreamer-plugins-vaapi
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define gst_so 1.6
%define gst_ver 1_6
%define soname 1

Name:           gstreamer-plugins-vaapi
Version:        1.6.0
Release:        3.1
Summary:        Gstreamer VA-API plugins
License:        LGPL-2.1+
Group:          Productivity/Multimedia/Other
Url:            https://github.com/01org/gstreamer-vaapi
Source0:        http://www.freedesktop.org/software/vaapi/releases/gstreamer-vaapi/gstreamer-vaapi-%{version}.tar.xz
Patch0:         gst_vaapi.autoconf.patch
BuildRequires:  Mesa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  libva-devel
BuildRequires:  pkgconfig
BuildRequires:  yasm
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.6.4
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(wayland-client) >= 1.0.0
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)
ExclusiveArch:  %ix86 x86_64
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
gstreamer-vaapi is a collection of GStreamer plugins and helper libraries that allow hardware accelerated video decoding through VA-API.

%prep
%setup -q -n gstreamer-vaapi-%{version}
%patch0 -p1

%build
autoreconf -fi
%configure --help || :
%configure \
	--disable-static \
	--disable-gtk-doc \
	--disable-gtk-doc-html \
	--enable-glx
make %{?_smp_mflags}

%install
%makeinstall
find %{buildroot} -ls
find %{buildroot}%{_libdir} -name '*.la' -delete -print
rm -rfv %{buildroot}%{_datadir}/gtk-doc

%files
%defattr(-,root,root,0755)
%doc AUTHORS COPYING.LIB NEWS README
%{_libdir}/gstreamer-*/*.so


%changelog
* Tue Jul 26 2016 olaf@aepfle.de
- Update to version 1.6.4
* Thu Dec 24 2015 zaitor@opensuse.org
- Update to version 0.7.0:
  + Add VP9 Decoder.
  + Improvements to HEVC(H265) decoder:
  - Fix the decoding of dependent slice segment.
  - Fix decoding of stream when it has temporal sublayers.
  - Added Workaround to recognize wrongly encoded main profile
    streams.
  - Add SEI Header parsing.
  - Fix the value assigning for delta_chroma_log2_weight_denom.
  - Fix default value assignment of pred_weight_table.
  - Fix ChromaOffsetL0/ChromaOffsetL1 calculation.
  - Add calculation of WpOffsetHalfRangeC.
  - Fix the scaling list scan order.
  - Fix the picture addition in dpb() based on spec H265 v3.
  - Fix the dpb_add() based on C.5.2.3.
  - Fix flushing of dpb for EOS/EOB nal.
  + Added infrastructure for handling corrupted pictures in h264
    decoder (bgo#703921, bgo#751434).
  + Add number of fixes and optimizations to GstContext sharing
    (bgo#757598).
  + Add API for dynamic detection of OpenGL API in use
    (bgo#753099).
  + Make vaapidecode + glimagesink combination work with opengl3
    (bgo#753099).
  + Fix segfault in vaapipostproc (bgo#752558).
  + Fix seeking while using GLTextureUpload for rendering
    (bgo#752929).
  + Ported JPEG decoder to new API/ABI changes in codecparser.
  + Removed gstvaapiuploader (bgo#752777).
  + Fix 0/1 frame-rate handling in encoder (bgo#744042).
  + Validate chroma sampling according to the VA's RT format in
    Encoder (bgo#744042).
  + Number of improvements in vaapi video memory handling
    (bgo#744042).
  + Stabilization of vaapidecodebin (bgo#749554, bgo#757957).
  + Wayland fixes: Don't return GST_FLOW_ERROR on flushing
    (bgo#753598).
  + Add yasm as build dependency.
  + Remvoved custom(non-official) debian parallel compilation
    option.
  + Fix multi-resolution video handling in vaapidecode
    (bgo#753914).
  + Adding stereoscopic/multiview upstream API support
    (bgo#750835).
  + Fixed fps calculation for for forced latency framerate
    (bgo#755040).
  + Fix build issues while disabling built-in codecparsers
    (bgo#754845).
  + Mark support for GStreamer 1.2 as obsolete.
  + Update libvpx submodule to 1.4.0.
  + Fix caps negotiation for meta:GstVideoGLTextureUploadMeta
    (bgo#756686).
  + Fixed leaked display instance in vaapidecodebin (bgo#757595).
* Tue Oct 27 2015 zaitor@opensuse.org
- Stop using wayland bcond, it does not work out for us.
- Add new %%define gst_so and %%define gst_ver and use suse_version
  to decide the value of these. Allowing package to be built with
  the different branches of gstreamer existing in older versions of
  openSUSE.
- Following this, subpackages get new name depending on what
  gst-branch they are built against.
* Tue Oct 20 2015 zaitor@opensuse.org
- Update to version 0.6.1:
  + Fix a possible segmentation fault using gstreamer 1.4
    (bgo#752558).
  + Don't loose the GLTextureUpload meta on seek (bgo#752929).
  + Remove in debian rules the option --with-gstreamer-api
    (bgo#753618).
  + Add in debian rules yasm as dependency.
  + Keep a copy of input codec state (bgo#753914).
  + Renegotiate if the input caps are not equal (bgo#750835).
  + Fix the FPS denominator and numerator (bgo#755040).
  + Initialize H264 PPS's slice_group_id (bgo#754845).
  + Verify for H264 MVC and H265 SPS when running configure
    (bgo#754845).
  + Link libgstvaapi_parse.so against libgstcodecparsers.so.
- Stop passing --with-gstreamer-api=1.0 to configure, no longer
  recognized.
* Mon Jul 20 2015 zaitor@opensuse.org
- Correct %%bconds, fixes build on SLE12 and openSUSE42 where we do
  not have wayland.
- Clean up spec.
- Update URL to new home.
* Fri Jul 17 2015 zaitor@opensuse.org
- Update to version 0.6.0:
  + Major changes:
  - Add HEVC(H265) Decoder.
  - Add HEVC(H265) Encoder.
  - Add VP8 Encoder.
  - Add JPEG Encoder.
  - Add a vaapidecodebin(vaapidecode->queue->vaapipostproc)
    element.
  - Add support for EGL.
  - Add Skin-Tone-Enhancement feature in vaapipostproc.
  - Add support for H.264 Multiview High profile encoding with
    more than 2 views.
  + Other Changes of interest:
  - Add support for loss of pictures in h264 decoder.
  - Add support for GstVideoGLTextureOrientation in plugins.
  - Add support for BGRA textures in plugins.
  - Add a simple-encoder test program that uses libgstvaapi for
    video encoding to elementary streams.
  - Add finer wayland frame control and many other optimizations.
  - Add packed SEI header message support in h264 encoder for CBR
    mode.
  - Add scaling of quality factor and Quantization tables for
    JPEG encoder.
  - Add GstColorBalance interface in vaapipostproc.
  - Add a handoff signal to vaapisink.
  - Add rounding control handling for VC1 simple and Main
    profile.
  - Record glconext supplied by downstream to enable run-time
    compatibility check.
  - Switch back to single thread implementation in vaapidecode.
  - Set decoding latency in vaapidecode by assuming realtime
    performance for the HW decoding.
  - Allow vaapidecode to connect with glimagesink, mark x11
    display as compatible with EGL.
  - Allow decoding of VC1 streams which contain user BDUs.
  - Use git.mk, a small Makefile to autogenerate .gitignore
    files.
  - Expose the overlay capability in vaapisink for compatibility
    with dvbsuboverlay.
  - Expose deinterlace property to vaapidecodebin.
  - Enable VPP element in vaapidecodebin only if there is HW
    support.
  - Fix autoplugging of vaapidecode in playbin for wmv/asf
    streams.
  - Fix multi-slice hevc encoding.
  - Fix ABBA deadlock between vaapisink and vaapipostproc if
    running in different threads.
  - Fix Seeking failure while using navseek in pipeline.
  - Fix PTS cache for MPEG2 GOP start.
  - Fix the wrong selection of passthrough mode in vaapipostproc.
  - Fix GstVaapiVideoPool related dead-lock.
  - Fix the race condition while setting drm device type.
  - Fix crash in vaapidecode if buffer outlives the decoder.
  - Fix memory leak in vaapidecode.
  - Fix multiple caps negotiation issues with vaapi elements.
  - Improve check for upstream element that requires DMABUF
    buffer pool.
  - Fix vaapisink memory leak in debug mode.
  - Fix crash when seeking mpeg2 strems.
  - Fix support for Wayland/EGL running alongside X11 (around 70+
    bug reports fixed).
  + GStreamer support corner:
  - Removed the support for GStreamer 0.10 and 1.0
  - GStreamer >= 1.2 is the minimal requirement
  - GStreamer 1.2.x is deprecated, and will be obsoleted in a
    future release
- Add a define soname and set it to 2, following upstream changes.
  Rename all sub-packages to get the new soname.
* Sun Mar 29 2015 zaitor@opensuse.org
- Update to version 0.5.10:
  + Add support for DRM Render-Nodes for headless operation.
  + Add support for VA surface buffer sharing with DMABUF and GEM
    handles.
  + Add support for v4l2src with io-mode={dmabuf,dmabuf-import}.
  + Drop support for VA/GLX specific APIs in libgstvaapi and
    vaapisink (bgo#736711).
  + Improvements to H.264 codecs:
  - Fix profile limits for encoding.
  - Fix pixel-aspect-ratio in the encoded stream.
  - Add decoding support for interlaced streams with
    repeat-first-field (RFF).
  - Fix decoding of interlaced streams in top-field-first order
    (TFF) (bgo#739291).
  - Fix decoding of UK DVB-T2 streams (bgo#739291).
  + Improvements to plugin elements:
  - Add support for dma_buf imports (Wind Yuan) (bgo#735362).
  - Allow for SW decoding fallbacks with unsupported profiles
    (bgo#730997).
  - Make vaapipostproc work with SW elements (bgo#720174,
    bgo#704078).
  - Allow vaapipostproc to integrate with GL downstream elements
    (bgo#735231).
  - Add support for high-quality scaling to vaapipostproc
    ("scale-method=hq").
  - Fix advanced deinterlacing when it is the unique filter
    applied.
  - Add GstColorBalance interface to vaapisink (bgo#722390).
  - Implement the GstNavigation interface into vaapisink
    (bgo#711479).
  - Allow rescaling of X11 window for vaapisink (bgo#711478).
  - Optimizations to vaapidecode thread handling (bgo#734616).
  - Fix deinterlacing from non VA memory buffers (bgo#726270).
  - Fix clearing of subtitle overlay.
  - Fix clearing of vaapipostproc state during restart.
- Bump soname following upstream changes.
* Sat Dec 13 2014 zaitor@opensuse.org
- Add pkgconfig(xrender) and pkgconfig(xrandr) BuildRequires: They
  were missing from the inital build.
* Tue Dec  9 2014 zaitor@opensuse.org
- Initial packaging.
